@@ -6,6 +6,16 @@ from FSEvents import *
 from PyObjCTools.TestSupport import *
 import os, time
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
+try:
+    long
+except NameError:
+    long = int
+
 class TestFSEvents (TestCase):
 
     def testValues(self):
@@ -30,7 +40,7 @@ class TestFSEvents (TestCase):
 
         self.assertHasAttr(FSEvents, 'kFSEventStreamEventIdSinceNow')
         self.assertIsInstance(FSEvents.kFSEventStreamEventIdSinceNow, (int, long))
-        self.assertEquals(FSEvents.kFSEventStreamEventIdSinceNow, -1)
+        self.assertEquals(FSEvents.kFSEventStreamEventIdSinceNow, 18446744073709551615)
 
 
 
@@ -60,7 +70,11 @@ class TestFSEvents (TestCase):
             v = FSEventStreamCopyPathsBeingWatched(ref)
             self.assertIsInstance(v, CFArrayRef)
             self.assertEqual(len(v), 2)
-            self.assertEqual(v, [os.path.realpath("/etc")[1:], os.path.realpath("/tmp")[1:]])
+
+            self.assertIn(v, [
+                    [os.path.realpath("/etc")[1:], os.path.realpath("/tmp")[1:]],
+                    [os.path.realpath("/etc"), os.path.realpath("/tmp")],
+                ])
 
             v = FSEventsGetCurrentEventId()
             self.assertIsInstance(v, (int, long))
